aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo/FONode.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/java/org/apache/fop/fo/FONode.java')
-rw-r--r--src/java/org/apache/fop/fo/FONode.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/java/org/apache/fop/fo/FONode.java b/src/java/org/apache/fop/fo/FONode.java
index 8314084d5..e507021f0 100644
--- a/src/java/org/apache/fop/fo/FONode.java
+++ b/src/java/org/apache/fop/fo/FONode.java
@@ -165,7 +165,7 @@ public abstract class FONode {
}
/**
* @param child child node to be added to the children of this node
*/
protected void addChildNode(FONode child) {
}
@@ -178,21 +178,21 @@ public abstract class FONode {
}
/**
* Return an iterator over all the children of this FObj.
* @return A ListIterator.
*/
- public ListIterator getChildren() {
+ public ListIterator getChildNodes() {
return null;
}
/**
* Return an iterator over the object's children starting
* at the pased node.
* @param childNode First node in the iterator
- * @return A ListIterator or null if childNode isn't a child of
+ * @return A ListIterator or null if child node isn't a child of
* this FObj.
*/
- public ListIterator getChildren(FONode childNode) {
+ public ListIterator getChildNodes(FONode childNode) {
return null;
}
@@ -165,7 +165,7 @@ public abstract class FONode {
}
/**
- * @param child child node to be added to the children of this node
+ * @param child child node to be added to the childNodes of this node
*/
protected void addChildNode(FONode child) {
@@ -178,21 +178,21 @@ public abstract class FONode {
}
/**
- * Return an iterator over all the children of this FObj.
+ * Return an iterator over all the child nodes of this FObj.
* @return A ListIterator.
*/
@@ -178,21 +178,21 @@ public abstract class FONode {
}
/**
- * Return an iterator over the object's children starting
+ * Return an iterator over the object's child nodes starting
* at the pased node.
* @param childNode First node in the iterator